==> openshift-model-operatorhub-6.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/NamedInstallStrategyFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NamedInstallStrategyFluent<A extends NamedInstallStrategyFluent<A>> extends BaseFluent<A>{
  public NamedInstallStrategyFluent() {
  }
  public NamedInstallStrategyFluent(NamedInstallStrategy instance) {
    instance = (instance != null ? instance : new NamedInstallStrategy());

    if (instance != null) {
      this.withSpec(instance.getSpec());
      this.withStrategy(instance.getStrategy());
      this.withSpec(instance.getSpec());
      this.withStrategy(instance.getStrategy());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private StrategyDetailsDeploymentBuilder spec;
  private String strategy;
  private Map<String,Object> additionalProperties;
  public StrategyDetailsDeployment buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(StrategyDetailsDeployment spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new StrategyDetailsDeploymentBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public boolean hasSpec() {
    return this.spec != null;
  }
  public SpecNested<A> withNewSpec() {
    return new SpecNested(null);
  }
  public SpecNested<A> withNewSpecLike(StrategyDetailsDeployment item) {
    return new SpecNested(item);
  }
  public SpecNested<A> editSpec() {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(null));
  }
  public SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(new StrategyDetailsDeploymentBuilder().build()));
  }
  public SpecNested<A> editOrNewSpecLike(StrategyDetailsDeployment item) {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(item));
  }
  public String getStrategy() {
    return this.strategy;
  }
  public A withStrategy(String strategy) {
    this.strategy=strategy; return (A) this;
  }
  public boolean hasStrategy() {
    return this.strategy != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamedInstallStrategyFluent that = (NamedInstallStrategyFluent) o;
    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(strategy, that.strategy)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(spec,  strategy,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (strategy != null) { sb.append("strategy:"); sb.append(strategy + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class SpecNested<N> extends StrategyDetailsDeploymentFluent<SpecNested<N>> implements Nested<N>{
    SpecNested(StrategyDetailsDeployment item) {
      this.builder = new StrategyDetailsDeploymentBuilder(this, item);
    }
    StrategyDetailsDeploymentBuilder builder;
    public N and() {
      return (N) NamedInstallStrategyFluent.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}

==> openshift-model-operatorhub-6.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/NamedInstallStrategyFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NamedInstallStrategyFluent<A extends NamedInstallStrategyFluent<A>> extends BaseFluent<A>{
  public NamedInstallStrategyFluent() {
  }
  
  public NamedInstallStrategyFluent(NamedInstallStrategy instance) {
    this.copyInstance(instance);
  }
  private StrategyDetailsDeploymentBuilder spec;
  private String strategy;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(NamedInstallStrategy instance) {
    instance = (instance != null ? instance : new NamedInstallStrategy());
  
    if (instance != null) {
        this.withSpec(instance.getSpec());
        this.withStrategy(instance.getStrategy());
        this.withSpec(instance.getSpec());
        this.withStrategy(instance.getStrategy());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public StrategyDetailsDeployment buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  
  public A withSpec(StrategyDetailsDeployment spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new StrategyDetailsDeploymentBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  
  public boolean hasSpec() {
    return this.spec != null;
  }
  
  public SpecNested<A> withNewSpec() {
    return new SpecNested(null);
  }
  
  public SpecNested<A> withNewSpecLike(StrategyDetailsDeployment item) {
    return new SpecNested(item);
  }
  
  public SpecNested<A> editSpec() {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(null));
  }
  
  public SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(new StrategyDetailsDeploymentBuilder().build()));
  }
  
  public SpecNested<A> editOrNewSpecLike(StrategyDetailsDeployment item) {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(item));
  }
  
  public String getStrategy() {
    return this.strategy;
  }
  
  public A withStrategy(String strategy) {
    this.strategy=strategy; return (A) this;
  }
  
  public boolean hasStrategy() {
    return this.strategy != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamedInstallStrategyFluent that = (NamedInstallStrategyFluent) o;
    if (!java.util.Objects.equals(spec, that.spec)) return false;
  
    if (!java.util.Objects.equals(strategy, that.strategy)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(spec,  strategy,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (strategy != null) { sb.append("strategy:"); sb.append(strategy + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class SpecNested<N> extends StrategyDetailsDeploymentFluent<SpecNested<N>> implements Nested<N>{
    SpecNested(StrategyDetailsDeployment item) {
      this.builder = new StrategyDetailsDeploymentBuilder(this, item);
    }
    StrategyDetailsDeploymentBuilder builder;
    
    public N and() {
      return (N) NamedInstallStrategyFluent.this.withSpec(builder.build());
    }
    
    public N endSpec() {
      return and();
    }
    
  
  }

}
